.. title:: Alphalens

.. mdinclude:: ../../README.md

.. toctree::
   :maxdepth: 4

   notebooks/overview
   notebooks/intraday_factor
   notebooks/event_study
   notebooks/pyfolio_integration
   api-reference
